@@ -1,4 +1,4 @@
-from models.grey_egm11 import GreyEGM_1_1
+from .models.grey_egm11 import GreyEGM_1_1
 
 class GreyTheory:
 
